@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,7 +29,7 @@ from logging import debug
 from nuitka import Tracing, VariableRegistry
 from nuitka.__past__ import iterItems  # Python3 compatibility.
 from nuitka.nodes.NodeMakingHelpers import getComputationResult
-from nuitka.utils import Utils
+from nuitka.PythonVersions import python_version
 
 from .VariableTraces import (
     VariableTraceAssign,
@@ -79,18 +79,19 @@ class CollectionTracingMixin:
         self.variable_actives[variable] = version
 
     def getCurrentVariableVersion(self, variable):
-        # Initialize variables on the fly.
-        if variable not in self.variable_actives:
+        try:
+            return self.variable_actives[variable]
+        except KeyError:
+            # Initialize variables on the fly.
             if not self.hasVariableTrace(variable, 0):
                 self.initVariable(variable)
 
             self.markCurrentVariableTrace(variable, 0)
 
-        assert variable in self.variable_actives, (variable, self)
-        return self.variable_actives[variable]
+            return self.variable_actives[variable]
 
     def getActiveVariables(self):
-        return tuple(self.variable_actives.keys())
+        return self.variable_actives.keys()
 
     def markActiveVariableAsUnknown(self, variable):
         current = self.getVariableCurrentTrace(
@@ -104,6 +105,7 @@ class CollectionTracingMixin:
                 variable = variable,
                 version  = version,
                 trace    = VariableTraceUnknown(
+                    owner    = self.owner,
                     variable = variable,
                     version  = version,
                     previous = current
@@ -150,10 +152,6 @@ class CollectionStartpointMixin:
         # this is.
         self.variable_traces = {}
 
-        # Cannot mess with local variables that much, as "locals" and "eval"
-        # calls may not yet be known.
-        self.unclear_locals = False
-
         self.break_collections = None
         self.continue_collections = None
         self.return_collections = None
@@ -275,6 +273,7 @@ class CollectionStartpointMixin:
 
     def _initVariableUnknown(self, variable):
         trace = VariableTraceUnknown(
+            owner    = self.owner,
             variable = variable,
             version  = 0,
             previous = None
@@ -290,8 +289,9 @@ class CollectionStartpointMixin:
 
     def _initVariableInit(self, variable):
         trace = VariableTraceInit(
+            owner    = self.owner,
             variable = variable,
-            version  = 0,
+            version  = 0
         )
 
         self.addVariableTrace(
@@ -304,6 +304,7 @@ class CollectionStartpointMixin:
 
     def _initVariableUninit(self, variable):
         trace = VariableTraceUninit(
+            owner    = self.owner,
             variable = variable,
             version  = 0,
             previous = None
@@ -317,12 +318,6 @@ class CollectionStartpointMixin:
 
         return trace
 
-    def assumeUnclearLocals(self):
-        self.unclear_locals = True
-
-    def hasUnclearLocals(self):
-        return self.unclear_locals
-
     def updateFromCollection(self, old_collection):
         VariableRegistry.updateFromCollection(old_collection, self)
 
@@ -354,9 +349,10 @@ class CollectionStartpointMixin:
             self.exception_collections = old_exception_collections
 
 class ConstraintCollectionBase(CollectionTracingMixin):
-    def __init__(self, name, parent):
+    def __init__(self, owner, name, parent):
         CollectionTracingMixin.__init__(self)
 
+        self.owner = owner
         self.parent = parent
         self.name = name
 
@@ -401,7 +397,7 @@ class ConstraintCollectionBase(CollectionTracingMixin):
 
                 self.markActiveVariableAsUnknown(variable)
 
-            elif Utils.python_version >= 300 or variable.isSharedTechnically():
+            elif python_version >= 300 or variable.isSharedTechnically():
                 # print variable
 
                 # TODO: Could be limited to shared variables that are actually
@@ -417,9 +413,6 @@ class ConstraintCollectionBase(CollectionTracingMixin):
 
         self.markActiveVariablesAsUnknown()
 
-    def assumeUnclearLocals(self):
-        self.parent.assumeUnclearLocals()
-
     def getVariableTrace(self, variable, version):
         return self.parent.getVariableTrace(variable, version)
 
@@ -439,6 +432,7 @@ class ConstraintCollectionBase(CollectionTracingMixin):
         variable = variable_ref.getVariable()
 
         variable_trace = VariableTraceAssign(
+            owner       = self.owner,
             assign_node = assign_node,
             variable    = variable,
             version     = version,
@@ -468,6 +462,7 @@ class ConstraintCollectionBase(CollectionTracingMixin):
         old_trace = self.getVariableCurrentTrace(variable)
 
         variable_trace = VariableTraceUninit(
+            owner    = self.owner,
             variable = variable,
             version  = version,
             previous = old_trace
@@ -708,6 +703,7 @@ class ConstraintCollectionBranch(ConstraintCollectionBase):
     def __init__(self, name, parent):
         ConstraintCollectionBase.__init__(
             self,
+            owner  = parent.owner,
             name   = name,
             parent = parent
         )
@@ -755,28 +751,30 @@ class ConstraintCollectionFunction(CollectionStartpointMixin,
                                    ConstraintCollectionBase,
                                    VariableUsageTrackingMixin):
     def __init__(self, parent, function_body):
-        assert function_body.isExpressionFunctionBody(), function_body
+        assert function_body.isExpressionFunctionBody() or \
+               function_body.isExpressionClassBody() or \
+               function_body.isExpressionGeneratorObjectBody() or \
+               function_body.isExpressionCoroutineObjectBody(), function_body
 
         CollectionStartpointMixin.__init__(self)
 
         ConstraintCollectionBase.__init__(
             self,
-            name   = "function " + str(function_body),
+            owner  = function_body,
+            name   = "function_" + str(function_body),
             parent = parent
         )
 
-        # TODO: Useless cyclic dependency.
-        self.function_body = function_body
-
 
 class ConstraintCollectionModule(CollectionStartpointMixin,
                                  ConstraintCollectionBase,
                                  VariableUsageTrackingMixin):
-    def __init__(self):
+    def __init__(self, module):
         CollectionStartpointMixin.__init__(self)
 
         ConstraintCollectionBase.__init__(
             self,
+            owner  = module,
             name   = "module",
             parent = None
         )
